@@ -2,7 +2,7 @@
 ## Stripe API - ~/lib/Net/API/Stripe/Payment/Source.pm
 ## Version v0.100.0
 ## Copyright(c) 2019 DEGUEST Pte. Ltd.
-## Author: Jacques Deguest <@sitael.tokyo.deguest.jp>
+## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2019/11/02
 ## Modified 2020/05/15
 ## 
@@ -12,10 +12,15 @@ package Net::API::Stripe::Payment::Source;
 BEGIN
 {
     use strict;
+    use warnings;
     use parent qw( Net::API::Stripe::Generic );
+    use vars qw( $VERSION );
     our( $VERSION ) = 'v0.100.0';
 };
 
+use strict;
+use warnings;
+
 sub id { return( shift->_set_get_scalar( 'id', @_ ) ); }
 
 sub object { return( shift->_set_get_scalar( 'object', @_ ) ); }
@@ -233,426 +238,422 @@ Stripe states this approach for card is deprecated in favour or PaymentIntent: L
 
 =head1 CONSTRUCTOR
 
-=over 4
-
-=item B<new>( %ARG )
+=head2 new( %ARG )
 
 Creates a new L<Net::API::Stripe::Payment::Source> object.
 
-=back
-
 =head1 METHODS
 
-=over 4
-
-=item B<id> string
+=head2 id string
 
 Unique identifier for the object.
 
-=item B<object> string, value is "source"
+=head2 object string, value is "source"
 
 String representing the object’s type. Objects of the same type share the same value.
 
-=item B<account> custom only string (expandable)
+=head2 account custom only string (expandable)
 
 The account this card belongs to. This attribute will not be in the card object if the card belongs to a customer or recipient instead.
 
 When expanded, this is a L<Net::API::Stripe::Connect::Account>
 
-=item B<account_holder_name> string
+=head2 account_holder_name string
 
 The name of the person or business that owns the bank account.
 
-=item B<account_holder_type> string
+=head2 account_holder_type string
 
 The type of entity that holds the account. This can be either individual or company.
 
-=item B<ach_credit_transfer>
+=head2 ach_credit_transfer
 
 If B<type> is set to C<ach_credit_transfer>, this is a L<Net::API::Stripe::Payment::Source::ACHCreditTransfer> object.
 
 It is not very clear in the Stripe API, but in the B<type> property, they mention "An additional hash is included on the source with a name matching this value. It contains additional information specific to the payment method (L<https://stripe.com/docs/sources>) used." :/
 
-=item B<ach_debit>
+=head2 ach_debit
 
 If B<type> is set to C<ach_debit>, this is a L<Net::API::Stripe::Payment::Source::ACHDebit> object.
 
 It is not very clear in the Stripe API, but in the B<type> property, they mention "An additional hash is included on the source with a name matching this value. It contains additional information specific to the payment method (L<https://stripe.com/docs/sources>) used." :/
 
-=item B<active> boolean
+=head2 active boolean
 
 True when this bitcoin receiver has received a non-zero amount of bitcoin.
 
-=item B<address> L<Net::API::Stripe::Address> object or hash
+=head2 address L<Net::API::Stripe::Address> object or hash
 
 This is a helper method. Provided with either a L<Net::API::Stripe::Address> object or a hash with same properties, this will assign all the address_* properties by calling its method.
 
-=item B<address> L<Net::API::Stripe::Address> object or hash
+=head2 address L<Net::API::Stripe::Address> object or hash
 
 This is a helper method. Provided with either a L<Net::API::Stripe::Address> object or a hash with same properties, this will assign all the address_* properties by calling its method.
 
-=item B<address_city> string
+=head2 address_city string
 
 City/District/Suburb/Town/Village.
 
-=item B<address_country> string
+=head2 address_country string
 
 Billing address country, if provided when creating card.
 
-=item B<address_line1> string
+=head2 address_line1 string
 
 Address line 1 (Street address/PO Box/Company name).
 
-=item B<address_line1_check> string
+=head2 address_line1_check string
 
 If address_line1 was provided, results of the check: pass, fail, unavailable, or unchecked.
 
-=item B<address_line2> string
+=head2 address_line2 string
 
 Address line 2 (Apartment/Suite/Unit/Building).
 
-=item B<address_state> string
+=head2 address_state string
 
 State/County/Province/Region.
 
-=item B<address_zip> string
+=head2 address_zip string
 
 ZIP or postal code.
 
-=item B<address_zip_check> string
+=head2 address_zip_check string
 
 If address_zip was provided, results of the check: pass, fail, unavailable, or unchecked.
 
-=item B<alipay>
+=head2 alipay
 
 If B<type> is set to C<alipay>, this is a L<Net::API::Stripe::Payment::Method::Details::Alipay> object.
 
-=item B<amount> integer
+=head2 amount integer
 
 A positive integer in the smallest currency unit (that is, 100 cents for $1.00, or 1 for ¥1, Japanese Yen being a zero-decimal currency) representing the total amount associated with the source. This is the amount for which the source will be chargeable once ready. Required for single_use sources.
 
-=item B<amount_received> positive integer or zero
+=head2 amount_received positive integer or zero
 
 The amount of currency to which bitcoin_amount_received has been converted.
 
-=item B<available_payout_methods> array
+=head2 available_payout_methods array
 
 A set of available payout methods for this card. Will be either ["standard"] or ["standard", "instant"]. Only values from this set should be passed as the method when creating a transfer.
 
-=item B<bancontact>
+=head2 bancontact
 
 If B<type> is set to C<bancontact>, this is a L<Net::API::Stripe::Payment::Method::Details::BanContact> object.
 
-=item B<bank_name> string
+=head2 bank_name string
 
 Name of the bank associated with the routing number (e.g., WELLS FARGO).
 
-=item B<bitcoin_amount> positive integer
+=head2 bitcoin_amount positive integer
 
 The amount of bitcoin that the customer should send to fill the receiver. The bitcoin_amount is denominated in Satoshi: there are 10^8 Satoshi in one bitcoin.
 
-=item B<bitcoin_amount_received> positive integer or zero
+=head2 bitcoin_amount_received positive integer or zero
 
 The amount of bitcoin that has been sent by the customer to this receiver.
 
-=item B<bitcoin_uri> string
+=head2 bitcoin_uri string
 
 This URI can be displayed to the customer as a clickable link (to activate their bitcoin client) or as a QR code (for mobile wallets).
 
-=item B<brand> string
+=head2 brand string
 
 Card brand. Can be American Express, Diners Club, Discover, JCB, MasterCard, UnionPay, Visa, or Unknown.
 
-=item B<card> object
+=head2 card object
 
 If B<type> is set to C<card>, this is a L<Net::API::Stripe::Payment::Card> object. See also L<https://stripe.com/docs/sources/cards>.
 
-=item B<card_present>
+=head2 card_present
 
 If B<type> is set to C<card_present>, this is a L<Net::API::Stripe::Payment::Method::Details::CardPresent> object.
 
-=item B<client_secret> string
+=head2 client_secret string
 
 The client secret of the source. Used for client-side retrieval using a publishable key.
 
-=item B<code_verification> hash
+=head2 code_verification hash
 
 Information related to the code verification flow. Present if the source is authenticated by a verification code (flow is code_verification).
 
 This is a L<Net::API::Stripe::Payment::Source::CodeVerification> object.
 
-=item B<country> string
+=head2 country string
 
 Two-letter ISO code representing the country of the card. You could use this attribute to get a sense of the international breakdown of cards you’ve collected.
 
-=item B<created> timestamp
+=head2 created timestamp
 
 Time at which the object was created. Measured in seconds since the Unix epoch.
 
-=item B<currency> currency
+=head2 currency currency
 
 Three-letter ISO code for the currency associated with the source. This is the currency for which the source will be chargeable once ready. Required for single_use sources.
 
-=item B<customer> string
+=head2 customer string
 
 The ID of the customer to which this source is attached. This will not be present when the source has not been attached to a customer. If it is expanded, this would be a L<Net::API::Stripe::Customer> object.
 
-=item B<cvc_check> string
+=head2 cvc_check string
 
 If a CVC was provided, results of the check: pass, fail, unavailable, or unchecked.
 
-=item B<description> string
+=head2 description string
 
 An arbitrary string attached to the object. Often useful for displaying to users.
 
-=item B<dynamic_last4> string
+=head2 dynamic_last4 string
 
 (For tokenized numbers only.) The last four digits of the device account number.
 
-=item B<email> string
+=head2 email string
 
 The customer’s email address, set by the API call that creates the receiver.
 
-=item B<eps>
+=head2 eps
 
 If B<type> is set to C<eps>, this is a L<Net::API::Stripe::Payment::Method::Details::EPS> object.
 
-=item B<exp_month> integer
+=head2 exp_month integer
 
 Two-digit number representing the card’s expiration month.
 
-=item B<exp_year> integer
+=head2 exp_year integer
 
 Four-digit number representing the card’s expiration year.
 
-=item B<filled> boolean
+=head2 filled boolean
 
 This flag is initially false and updates to true when the customer sends the bitcoin_amount to this receiver.
 
-=item B<fingerprint> string
+=head2 fingerprint string
 
 Uniquely identifies this particular card number. You can use this attribute to check whether two customers who’ve signed up with you are using the same card number, for example.
 
-=item B<flow> string
+=head2 flow string
 
 The authentication flow of the source. flow is one of redirect, receiver, code_verification, none.
 
-=item B<livemode> boolean
+=head2 livemode boolean
 
 Has the value true if the object exists in live mode or the value false if the object exists in test mode.
 
-=item B<funding> string
+=head2 funding string
 
 Card funding type. Can be credit, debit, prepaid, or unknown.
 
-=item B<giropay>
+=head2 giropay
 
 If B<type> is set to C<giropay>, this is a L<Net::API::Stripe::Payment::Method::Details::Giropay> object.
 
-=item B<ideal>
+=head2 ideal
 
 If B<type> is set to C<ideal>, this is a L<Net::API::Stripe::Payment::Method::Details::Ideal> object.
 
-=item B<inbound_address> string
+=head2 inbound_address string
 
 A bitcoin address that is specific to this receiver. The customer can send bitcoin to this address to fill the receiver.
 
-=item B<klarna>
+=head2 klarna
 
 If B<type> is set to C<klarna>, this is a L<Net::API::Stripe::Payment::Method::Details::Klarna> object.
 
-=item B<last4> string
+=head2 last4 string
 
 The last four digits of the card.
 
-=item B<livemode> boolean
+=head2 livemode boolean
 
 Has the value true if the object exists in live mode or the value false if the object exists in test mode.
 
-=item B<metadata> hash
+=head2 metadata hash
 
 Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
 
-=item B<multibanco>
+=head2 multibanco
 
 If B<type> is set to C<multibanco>, this is a L<Net::API::Stripe::Payment::Method::Details::MultiBanco> object.
 
-=item B<name> string
+=head2 name string
 
 Cardholder name.
 
-=item B<p24>
+=head2 p24
 
 If B<type> is set to C<p24>, this is a L<Net::API::Stripe::Payment::Method::Details::P24> object.
 
-=item B<payment> string
+=head2 payment string
 
 The ID of the payment created from the receiver, if any. Hidden when viewing the receiver with a publishable key.
 
-=item B<owner> hash
+=head2 owner hash
 
 Information about the owner of the payment instrument that may be used or required by particular source types.
 
 This is a L<Net::API::Stripe::Payment::Source::Owner> object.
 
-=item B<payment_amount> positive integer
+=head2 payment_amount positive integer
 
 If the Alipay account object is not reusable, the exact amount that you can create a charge for.
 
-=item B<payment_currency> currency
+=head2 payment_currency currency
 
 If the Alipay account object is not reusable, the exact currency that you can create a charge for.
 
-=item B<receiver> hash
+=head2 receiver hash
 
 Information related to the receiver flow. Present if the source is a receiver (flow is receiver).
 
 This is a L<Net::API::Stripe::Payment::Source::Receiver> object.
 
-=item B<recipient> string (expandable)
+=head2 recipient string (expandable)
 
 The recipient that this card belongs to. This attribute will not be in the card object if the card belongs to a customer or account instead.
 
 When expanded, this is a L<Net::API::Stripe::Customer>.
 
-=item B<redirect> hash
+=head2 redirect hash
 
 Information related to the redirect flow. Present if the source is authenticated by a redirect (flow is redirect).
 
 This is a L<Net::API::Stripe::Payment::Source::Redirect> object.
 
-=item B<reusable> boolean
+=head2 reusable boolean
 
 True if you can create multiple payments using this account. If the account is reusable, then you can freely choose the amount of each payment.
 
-=item B<refund_address> string
+=head2 refund_address string
 
-=item B<routing_number> string
+The refund address of this bitcoin receiver.
+
+=head2 routing_number string
 
 The routing transit number for the bank account.
 
-=item B<sofort> hash
+=head2 sofort hash
 
 If B<type> is set to C<sofort>, this is a L<Net::API::Stripe::Payment::Details::Sofort> virtual object, ie it is created dynamically by L<Nodule::Generic/"set_get_hash_as_object">
 
-=item B<source_order> hash
+=head2 source_order hash
 
 Information about the items and shipping associated with the source. Required for transactional credit (for example Klarna) sources before you can charge it. This is a L<Net::API::Stripe::Order> object.
 
-=over 8
+=over 4
 
-=item B<amount> integer
+=item I<amount> integer
 
 A positive integer in the smallest currency unit (that is, 100 cents for $1.00, or 1 for ¥1, Japanese Yen being a zero-decimal currency) representing the total amount for the order.
 
-=item B<currency> currency
+=item I<currency> currency
 
 Three-letter ISO currency code, in lowercase. Must be a supported currency.
 
-=item B<email> string
+=item I<email> string
 
 The email address of the customer placing the order.
 
-=item B<items> array of hashes
+=item I<items> array of hashes
 
 List of items constituting the order. This is an array of L<Net::API::Stripe::Order::Item> objects.
 
-=item B<shipping> hash
+=item I<shipping> hash
 
 The shipping address for the order. Present if the order is for goods to be shipped. This is a L<Net::API::Stripe::Shipping> object
 
 =back
 
-=item B<statement_descriptor> string
+=head2 statement_descriptor string
 
 Extra information about a source. This will appear on your customer’s statement every time you charge the source.
 
-=item B<status> string
+=head2 status string
 
 The status of the source, one of canceled, chargeable, consumed, failed, or pending. Only chargeable sources can be used to create a charge.
 
-=item B<stripe_account>
+=head2 stripe_account
 
 If B<type> is set to C<stripe_account>, this is a L<Net::API::Stripe::Payment::Method::Details::StripeAccount> object.
 
-=item B<tokenization_method> string
+=head2 tokenization_method string
 
 If the card number is tokenized, this is the method that was used. Can be apple_pay or google_pay.
 
-=item B<transactions>
+=head2 transactions
 
 A list (L<Net::API::Stripe::List>) of L<Net::API::Stripe::Bitcoin::Transaction> object
 
-=item B<type> string
+=head2 type string
 
 The type of the source. The type is a payment method, one of ach_credit_transfer, ach_debit, alipay, bancontact, card, card_present, eps, giropay, ideal, multibanco, klarna, p24, sepa_debit, sofort, three_d_secure, or wechat. An additional hash is included on the source with a name matching this value. It contains additional information specific to the payment method (L<https://stripe.com/docs/sources>) used.
 
-=item B<uncaptured_funds> boolean
+=head2 uncaptured_funds boolean
 
 This receiver contains uncaptured funds that can be used for a payment or refunded.
 
-=item B<usage> string
+=head2 usage string
 
 Either reusable or single_use. Whether this source should be reusable or not. Some source types may or may not be reusable by construction, while others may leave the option at creation. If an incompatible value is passed, an error will be returned.
 
-=item B<used> boolean
+=head2 used boolean
 
 Whether this Alipay account object has ever been used for a payment.
 
-=item B<used_for_payment> boolean
+=head2 used_for_payment boolean
 
-=item B<username> string
+Indicate if this source is used for payment.
+
+=head2 username string
 
 The username for the Alipay account.
 
-=item B<wechat>
+=head2 wechat
 
-If B<type> is set to C<wechat>, this is a L<Net::API::Stripe::Payment::Method::Details::WeChat> object.
-
-=back
+If L</type> is set to C<wechat>, this is a L<Net::API::Stripe::Payment::Method::Details::WeChat> object.
 
 =head1 API SAMPLE
 
-	{
-	  "id": "src_fake123456789",
-	  "object": "source",
-	  "ach_credit_transfer": {
-		"account_number": "test_52796e3294dc",
-		"routing_number": "110000000",
-		"fingerprint": "anvbmbvmnbvmab",
-		"bank_name": "TEST BANK",
-		"swift_code": "TSTEZ122"
-	  },
-	  "amount": null,
-	  "client_secret": "src_client_secret_fake123456789",
-	  "created": 1571314413,
-	  "currency": "jpy",
-	  "flow": "receiver",
-	  "livemode": false,
-	  "metadata": {},
-	  "owner": {
-		"address": null,
-		"email": "jenny.rosen@example.com",
-		"name": null,
-		"phone": null,
-		"verified_address": null,
-		"verified_email": null,
-		"verified_name": null,
-		"verified_phone": null
-	  },
-	  "receiver": {
-		"address": "121042882-38381234567890123",
-		"amount_charged": 0,
-		"amount_received": 0,
-		"amount_returned": 0,
-		"refund_attributes_method": "email",
-		"refund_attributes_status": "missing"
-	  },
-	  "statement_descriptor": null,
-	  "status": "pending",
-	  "type": "ach_credit_transfer",
-	  "usage": "reusable"
-	}
+    {
+      "id": "src_fake123456789",
+      "object": "source",
+      "ach_credit_transfer": {
+        "account_number": "test_52796e3294dc",
+        "routing_number": "110000000",
+        "fingerprint": "anvbmbvmnbvmab",
+        "bank_name": "TEST BANK",
+        "swift_code": "TSTEZ122"
+      },
+      "amount": null,
+      "client_secret": "src_client_secret_fake123456789",
+      "created": 1571314413,
+      "currency": "jpy",
+      "flow": "receiver",
+      "livemode": false,
+      "metadata": {},
+      "owner": {
+        "address": null,
+        "email": "jenny.rosen@example.com",
+        "name": null,
+        "phone": null,
+        "verified_address": null,
+        "verified_email": null,
+        "verified_name": null,
+        "verified_phone": null
+      },
+      "receiver": {
+        "address": "121042882-38381234567890123",
+        "amount_charged": 0,
+        "amount_received": 0,
+        "amount_returned": 0,
+        "refund_attributes_method": "email",
+        "refund_attributes_status": "missing"
+      },
+      "statement_descriptor": null,
+      "status": "pending",
+      "type": "ach_credit_transfer",
+      "usage": "reusable"
+    }
 
 =head1 HISTORY
 
